@@ -7,22 +7,25 @@
 #' \url{https://www.sec.gov/Archives/edgar/daily-index/}. It strips headers 
 #' and converts this daily filing information into dataframe format.
 #' Function creates new directory 'Daily Indexes' into working directory 
-#' to save these downloaded daily master index files in Rda format.
+#' to save these downloaded daily master index files in Rda format. According to SEC 
+#' EDGAR's guidelines a user also needs to declare user agent. 
 #' 
-#' @usage getDailyMaster(input.date)
+#' @usage getDailyMaster(input.date, useragent)
 #' 
 #' @param input.date in character format 'mm/dd/YYYY'.
 #' 
+#' @param useragent Should be in the form of "Your Name Contact@domain.com"
+#' 
 #' @return Function returns filings information in a dataframe format.
 #'   
 #' @examples
 #' \dontrun{
 #' 
-#' output <- getDailyMaster('08/09/2016')
+#' output <- getDailyMaster('08/09/2016', useragent)
 #'} 
 
 
-getDailyMaster <- function(input.date) {
+getDailyMaster <- function(input.date, useragent="") {
     
     
     dir.create("Daily Indexes")
@@ -67,13 +70,38 @@ getDailyMaster <- function(input.date) {
       return(dmethod)
     }
     
+    ### Check for valid user agent
+    if(useragent != ""){
+      # Check user agent
+      bb <- any(grepl( "lonare.gunratan@gmail.com|glonare@uncc.edu|bharatspatil@gmail.com",
+                       useragent, ignore.case = T))
+      
+      if(bb == TRUE){
+        
+        cat("Please provide a valid User Agent. 
+      Visit https://www.sec.gov/os/accessing-edgar-data 
+      for more information")
+        return()
+      }
+      
+    }else{
+      
+      cat("Please provide a valid User Agent. 
+      Visit https://www.sec.gov/os/accessing-edgar-data 
+      for more information")
+      return()
+    }
+    
     
     
     # function to download file and return FALSE if download error
-    DownloadSECFile <- function(link, dfile, dmethod) {
+    DownloadSECFile <- function(link, dfile, dmethod, useragent) {
       
       tryCatch({
-        utils::download.file(link, dfile, method = dmethod, quiet = TRUE)
+        utils::download.file(link, dfile, method = dmethod, quiet = TRUE,
+                             headers = c("User-Agent" = useragent,
+                                         "Accept-Encoding"= "deflate, gzip",
+                                         "Host"= "www.sec.gov"))
         return(TRUE)
       }, error = function(e) {
         return(FALSE)
@@ -82,6 +110,39 @@ getDailyMaster <- function(input.date) {
     }
     
     
+    DownloadSECFile2 <- function(link, dfile, dmethod, useragent) {
+
+      ### Go inside a loop to download
+      i = 1
+      
+      while(TRUE){
+        
+        res <- DownloadSECFile(link, dfile, dmethod, useragent)
+        
+        if (res){
+          
+          if (file.info(dfile)$size < 6000){
+            
+            aa <- readLines(dfile)
+            
+            if(any(grepl("For security purposes, and to ensure that the public service remains available to users, this government computer system", aa)) == FALSE){
+              
+              break
+            }
+            
+          }else{
+            
+            break
+          }
+        }
+        
+        
+        i = i + 1 
+        Sys.sleep(10) ## Wait for multiple of 10 seconds to ease request load on SEC server. 
+      }
+      return(TRUE)
+    }
+    
     # function for downloading daily Index
     GetDailyInfo <- function(day, month, year) {
         
@@ -105,26 +166,20 @@ getDailyMaster <- function(input.date) {
         down.success = FALSE
         
         if (year < 1999) {
-            fun.return3 <- DownloadSECFile(link3, filename, dmethod)
-            if (fun.return3 == 1) {
-                down.success = TRUE
-            }
+          down.success <- DownloadSECFile2(link3, filename, dmethod, useragent)
         }
         
         if (year > 1998 && year < 2012) {
-            fun.return4 <- DownloadSECFile(link4, filename, dmethod)
-            if (fun.return4 == 1) {
-                down.success = TRUE
-            }
+          down.success <- DownloadSECFile2(link4, filename, dmethod, useragent)
         }
         
         if (year > 2011) {
-            fun.return1 <- DownloadSECFile(link1, filename, dmethod)
+            fun.return1 <- DownloadSECFile2(link1, filename, dmethod, useragent)
             if (fun.return1 && file.size(filename) > 500) {
                 down.success = TRUE
                 
             } else {
-                fun.return2 <- DownloadSECFile(link2, filename, dmethod)
+                fun.return2 <- DownloadSECFile2(link2, filename, dmethod, useragent)
                 if (fun.return2) {
                   down.success = TRUE
                 }
