@@ -11,36 +11,64 @@
 #' not already been downloaded. It then reads, cleans, and parse the required section 
 #' from the filings. It creates a new directory with the name "MD&A section text" 
 #' in the current working directory to save scrapped "Item 7" sections in text format. 
-#' It considers "10-K", "10-K405", "10KSB", and "10KSB40" form types as annual statements.
+#' It considers "10-K", "10-K405", "10KSB", and "10KSB40" form types as annual statements. 
+#' According to SEC EDGAR's guidelines a user also needs to declare user agent. 
 #' 
 #'   
-#' @usage getMgmtDisc(cik.no, filing.year)
+#' @usage getMgmtDisc(cik.no, filing.year, useragent)
 #' 
 #' @param cik.no vector of firm CIK numbers in integer format. Suppress leading 
 #' zeroes from CIKs.
 #' 
 #' @param filing.year vector of four digit numeric year
 #' 
+#' @param useragent Should be in the form of "Your Name Contact@domain.com"
+#' 
 #' @return Function saves scrapped "Item 7" section from annual filings in 
 #' "MD&A section text" directory present in the working directory. 
 #' The output dataframe contains information on CIK number, company name, 
-#' date of filing, and accession number.
+#' date of filing, and accession number. For a successful extraction of M&A section, 
+#' 'extract.status' column returns 1, other return 0 for failed extraction. 
 #'   
 #' @examples
 #' \dontrun{
 #' 
-#' output <- getMgmtDisc(cik.no = c(1000180, 38079), filing.year = 2005)
+#' output <- getMgmtDisc(cik.no = c(1000180, 38079), filing.year = 2005, useragent)
 #' 
 #' ## saves scrapped "Item 7" section from 10-K filings for CIKs in 
 #' "MD&A section text" directory present in the working directory. 
 #' Also, it provides filing information in the output datframe.
 #' 
 #' output <- getMgmtDisc(cik.no = c(1000180, 38079), 
-#'                       filing.year = c(2005, 2006))
+#'                       filing.year = c(2005, 2006), useragent)
 #'}
 
-getMgmtDisc <- function(cik.no, filing.year ) {
+getMgmtDisc <- function(cik.no, filing.year, useragent="" ) {
     
+  
+  ### Check for valid user agent
+  if(useragent != ""){
+    # Check user agent
+    bb <- any(grepl( "lonare.gunratan@gmail.com|glonare@uncc.edu|bharatspatil@gmail.com",
+                     useragent, ignore.case = T))
+    
+    if(bb == TRUE){
+      
+      cat("Please provide a valid User Agent. 
+      Visit https://www.sec.gov/os/accessing-edgar-data 
+      for more information")
+      return()
+    }
+    
+  }else{
+    
+    cat("Please provide a valid User Agent. 
+      Visit https://www.sec.gov/os/accessing-edgar-data 
+      for more information")
+    return()
+  }
+  
+  
     f.type <- c("10-K", "10-K405","10KSB", "10KSB40")
     # 10-K, 10-K405, 10-KSB, 10-KT, 10KSB, 10KSB40, and 10KT405 filings in the EDGAR database
 
@@ -51,7 +79,7 @@ getMgmtDisc <- function(cik.no, filing.year ) {
     }
     
     output <- getFilings(cik.no = cik.no, form.type = f.type , filing.year, 
-						 quarter = c(1, 2, 3, 4), downl.permit = "y")
+						 quarter = c(1, 2, 3, 4), downl.permit = "y", useragent)
     
     if (is.null(output)){
       cat("No annual statements found for given CIK(s) and year(s).")
@@ -137,15 +165,52 @@ getMgmtDisc <- function(cik.no, filing.year ) {
         
         
         # Get MD&A sections
-        startline <- grep("^Item\\s{0,}7[^A]", f.text, ignore.case = TRUE)
-        endline <- grep("^Item\\s{0,}7A", f.text, ignore.case = TRUE)
-        
-        # if dont have Item 7A, then take upto Item 8
-        if (length(endline) == 0) {
+        # M&D section is in Item 7 for 10-K, 10-K405 and in Item 6 for 10KSB and 10KSB40
+        if (f.type == "10-K" | f.type == "10-K405"){
+          
+          startline <- grep("^Item\\s{0,}7\\.{0,}[^A.|\\(A\\)]", f.text, ignore.case = TRUE)
+          endline <- grep("^Item\\s{0,}7\\.{0,}(A|\\(A\\)|\\.A)", f.text, ignore.case = TRUE)
+          
+          # if don't have Item 7A, then take up to Item 8
+          # but also check if Item 7A match different number of times to Item 7.
+          # if this is the case and Item 7A match is before the second or subsequent match for Item 7, extraction will be faulty use Item 8 as delimiter in this case
+          if (length(endline) == 0 | (length(endline) != length(startline) & !all(endline - startline >= 0))) {
             endline <- grep("^Item\\s{0,}8", f.text, ignore.case = TRUE)
+          }
+          
+          # if more than one match is identified, determine which one to use
+          # use the match that that covers the most lines 
+          # when a table of content in the source of the double match there will be few lines between start and end line
+          # so take the match that covers more lines
+          if (length(startline) >= 2 && length(endline)  >= 2) {
+            startline <- startline[which.max(endline - startline)]
+            endline <- endline[which.max(endline - startline)]
+          }
+        } else {
+          startline <- grep("^Item\\s{0,}6", f.text, ignore.case = TRUE)
+          endline <- grep("^Item\\s{0,}7", f.text, ignore.case = TRUE)
+          
+          # if more than one match is identified, determine which one to use
+          # check if both startline and endline have two matches
+          # if this is the case use the match where start line is before endline
+          if (length(endline) != length(startline) & !all(endline - startline >= 0)) {
+            startline <- startline[which.max(endline - startline)]
+            endline <- endline[which.max(endline - startline)]
+          }
+          
+          # use the match that that covers the most lines 
+          # when a table of content in the source of the double match there will be few lines between start and end line
+          # so take the match that covers more lines
+          if (length(startline) >= 2 && length(endline) >= 2) {
+            startline <- startline[which.max(endline - startline)]
+            endline <- endline[which.max(endline - startline)]
+          }
+          
         }
         
+        
         md.dicusssion <- NA
+        words.count <- 0
         
         if (length(startline) != 0 && length(endline) != 0) {
             
