@@ -8,8 +8,9 @@
 #' it automatically downloads the filings which are not already been downloaded.
 #' It then reads, cleans, and computes sentiment measures for these filings. 
 #' The function returns a dataframe with filing information and sentiment measures.
+#' According to SEC EDGAR's guidelines a user also needs to declare user agent. 
 #' 
-#' @usage getSentiment(cik.no, form.type, filing.year)
+#' @usage getSentiment(cik.no, form.type, filing.year, useragent)
 #' 
 #' @param cik.no vector of CIK number of firms in integer format. Suppress leading 
 #' zeroes from CIKs. Keep cik.no = 'ALL' if needs to download for all CIKs.
@@ -19,6 +20,8 @@
 #'
 #' @param filing.year vector of four digit numeric year
 #' 
+#' @param useragent Should be in the form of "Your Name Contact@domain.com"
+#' 
 #' @return Function returns dataframe containing CIK number, company name, 
 #' date of filing, accession number, and various sentiment measures. 
 #' This function takes the help of Loughran-McDonald (L&M) sentiment 
@@ -76,19 +79,43 @@
 #' \dontrun{
 #' 
 #' senti.df <- getSentiment(cik.no = c('1000180', '38079'), 
-#'                          form.type = '10-K', filing.year = 2006) 
+#'                          form.type = '10-K', filing.year = 2006, useragent) 
 #'                          
 #' ## Returns dataframe with sentiment measures of firms with CIKs 
 #' 1000180 and 38079 filed in year 2006 for form type '10-K'.
 #' 
 #' senti.df <- getSentiment(cik.no = '38079', form.type = c('10-K', '10-Q'), 
-#'                          filing.year = c(2005, 2006))
+#'                          filing.year = c(2005, 2006), useragent)
 #'}
 
-getSentiment <- function(cik.no, form.type, filing.year) {
+getSentiment <- function(cik.no, form.type, filing.year, useragent= "") {
     
+  
+  ### Check for valid user agent
+  if(useragent != ""){
+    # Check user agent
+    bb <- any(grepl( "lonare.gunratan@gmail.com|glonare@uncc.edu|bharatspatil@gmail.com",
+                     useragent, ignore.case = T))
+    
+    if(bb == TRUE){
+      
+      cat("Please provide a valid User Agent. 
+      Visit https://www.sec.gov/os/accessing-edgar-data 
+      for more information")
+      return()
+    }
+    
+  }else{
+    
+    cat("Please provide a valid User Agent. 
+      Visit https://www.sec.gov/os/accessing-edgar-data 
+      for more information")
+    return()
+  }
+  
+  
     output <- getFilings(cik.no, form.type, filing.year, quarter = c(1, 2, 3, 4), 
-						 downl.permit = "y")
+						 downl.permit = "y", useragent)
     
     if (is.null(output)){
       # cat("Please check the CIK number.")
